@@ -1,9 +1,10 @@
 /*
-  Copyright (c) 2013-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013-2020 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
+  under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
 
   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -21,14 +22,17 @@
 #include "messageviewer_export.h"
 #include <QWidget>
 
-namespace MessageViewer
-{
+namespace MessageViewer {
 class PrintingSettingsPrivate;
+/**
+ * @brief The PrintingSettings class
+ * @author Laurent Montel <montel@kde.org>
+ */
 class MESSAGEVIEWER_EXPORT PrintingSettings : public QWidget
 {
     Q_OBJECT
 public:
-    explicit PrintingSettings(QWidget *parent = Q_NULLPTR);
+    explicit PrintingSettings(QWidget *parent = nullptr);
     ~PrintingSettings();
 
     void save();
